@@ -1,9 +1,10 @@
 // file      : xsde/cxx/parser/non-validating/name-stl.cxx
 // author    : Boris Kolpackov <boris@codesynthesis.com>
-// copyright : Copyright (c) 2005-2008 Code Synthesis Tools CC
+// copyright : Copyright (c) 2005-2011 Code Synthesis Tools CC
 // license   : GNU GPL v2 + exceptions; see accompanying LICENSE file
 
 #include <xsde/cxx/parser/non-validating/name-stl.hxx>
+#include <xsde/cxx/parser/non-validating/string-common.hxx>
 
 namespace xsde
 {
@@ -36,8 +37,7 @@ namespace xsde
         std::string name_pimpl::
         post_name ()
         {
-          ro_string tmp (str_);
-          str_.resize (trim_right (tmp));
+          string_common::process_facets (str_, _facets ());
 
           std::string r;
           r.swap (str_);
