@@ -1,10 +1,14 @@
 // file      : xsde/cxx/serializer/non-validating/nmtokens-stl.cxx
 // author    : Boris Kolpackov <boris@codesynthesis.com>
-// copyright : Copyright (c) 2005-2009 Code Synthesis Tools CC
+// copyright : Copyright (c) 2005-2011 Code Synthesis Tools CC
 // license   : GNU GPL v2 + exceptions; see accompanying LICENSE file
 
 #include <xsde/cxx/serializer/non-validating/nmtokens-stl.hxx>
 
+#ifdef XSDE_CUSTOM_ALLOCATOR
+#  include <xsde/cxx/allocator.hxx>
+#endif
+
 namespace xsde
 {
   namespace cxx
@@ -16,8 +20,16 @@ namespace xsde
         nmtokens_simpl::
         ~nmtokens_simpl ()
         {
-          if (free_)
-            delete const_cast<string_sequence*> (value_);
+          if (free_ && value_)
+          {
+            string_sequence* v = const_cast<string_sequence*> (value_);
+#ifndef XSDE_CUSTOM_ALLOCATOR
+            delete v;
+#else
+            v->~string_sequence ();
+            cxx::free (v);
+#endif
+          }
         }
 
         void nmtokens_simpl::
@@ -91,7 +103,13 @@ namespace xsde
 
           if (free_)
           {
-            delete const_cast<string_sequence*> (value_);
+            string_sequence* v = const_cast<string_sequence*> (value_);
+#ifndef XSDE_CUSTOM_ALLOCATOR
+            delete v;
+#else
+            v->~string_sequence ();
+            cxx::free (v);
+#endif
             value_ = 0;
           }
         }
