@@ -1,10 +1,14 @@
 // file      : xsde/cxx/serializer/non-validating/string.cxx
 // author    : Boris Kolpackov <boris@codesynthesis.com>
-// copyright : Copyright (c) 2005-2008 Code Synthesis Tools CC
+// copyright : Copyright (c) 2005-2011 Code Synthesis Tools CC
 // license   : GNU GPL v2 + exceptions; see accompanying LICENSE file
 
 #include <xsde/cxx/serializer/non-validating/string.hxx>
 
+#ifdef XSDE_CUSTOM_ALLOCATOR
+#  include <xsde/cxx/allocator.hxx>
+#endif
+
 namespace xsde
 {
   namespace cxx
@@ -16,8 +20,15 @@ namespace xsde
         string_simpl::
         ~string_simpl ()
         {
-          if (free_)
-            delete[] const_cast<char*> (value_);
+          if (free_ && value_)
+          {
+            char* v = const_cast<char*> (value_);
+#ifndef XSDE_CUSTOM_ALLOCATOR
+            delete[] v;
+#else
+            cxx::free (v);
+#endif
+          }
         }
 
         void string_simpl::
@@ -33,7 +44,12 @@ namespace xsde
 
           if (free_)
           {
-            delete[] const_cast<char*> (value_);
+            char* v = const_cast<char*> (value_);
+#ifndef XSDE_CUSTOM_ALLOCATOR
+            delete[] v;
+#else
+            cxx::free (v);
+#endif
             value_ = 0;
           }
         }
