@@ -1,11 +1,16 @@
 // file      : xsde/cxx/serializer/validating/nmtoken.cxx
 // author    : Boris Kolpackov <boris@codesynthesis.com>
-// copyright : Copyright (c) 2005-2009 Code Synthesis Tools CC
+// copyright : Copyright (c) 2005-2011 Code Synthesis Tools CC
 // license   : GNU GPL v2 + exceptions; see accompanying LICENSE file
 
 #include <xsde/cxx/xml/char-table.hxx>
 
 #include <xsde/cxx/serializer/validating/nmtoken.hxx>
+#include <xsde/cxx/serializer/validating/string-common.hxx>
+
+#ifdef XSDE_CUSTOM_ALLOCATOR
+#  include <xsde/cxx/allocator.hxx>
+#endif
 
 namespace xsde
 {
@@ -18,8 +23,15 @@ namespace xsde
         nmtoken_simpl::
         ~nmtoken_simpl ()
         {
-          if (free_)
-            delete[] const_cast<char*> (value_);
+          if (free_ && value_)
+          {
+            char* v = const_cast<char*> (value_);
+#ifndef XSDE_CUSTOM_ALLOCATOR
+            delete[] v;
+#else
+            cxx::free (v);
+#endif
+          }
         }
 
         void nmtoken_simpl::
@@ -45,13 +57,24 @@ namespace xsde
           }
 
           if (ok)
-            _characters (value_);
+          {
+            if (string_common::validate_facets (
+                  value_, _facets (), _context ()))
+            {
+              _characters (value_);
+            }
+          }
           else
             _schema_error (schema_error::invalid_nmtoken_value);
 
           if (free_)
           {
-            delete[] const_cast<char*> (value_);
+            char* v = const_cast<char*> (value_);
+#ifndef XSDE_CUSTOM_ALLOCATOR
+            delete[] v;
+#else
+            cxx::free (v);
+#endif
             value_ = 0;
           }
         }
