@@ -1,9 +1,10 @@
 // file      : xsde/cxx/serializer/validating/normalized-string-stl.cxx
 // author    : Boris Kolpackov <boris@codesynthesis.com>
-// copyright : Copyright (c) 2005-2008 Code Synthesis Tools CC
+// copyright : Copyright (c) 2005-2011 Code Synthesis Tools CC
 // license   : GNU GPL v2 + exceptions; see accompanying LICENSE file
 
 #include <xsde/cxx/serializer/validating/normalized-string-stl.hxx>
+#include <xsde/cxx/serializer/validating/string-common.hxx>
 
 namespace xsde
 {
@@ -35,13 +36,19 @@ namespace xsde
               break;
           }
 
-          if (*s == '\0')
-            _characters (tmp.c_str (), tmp.size ());
-          else
+          if (*s != '\0')
+          {
             _schema_error (schema_error::invalid_normalized_string_value);
+            return;
+          }
+
+          if (!string_common::validate_facets (
+                tmp.c_str (), tmp.size (), _facets (), _context ()))
+            return;
+
+          _characters (tmp.c_str (), tmp.size ());
         }
       }
     }
   }
 }
-
